module.exports = defineTest({
	description: 'handles deoptimizations of logical expression while they are inlcuded (#3324)'
});
